# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/wasm/v3/wasm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/wasm/v3/wasm.proto',
  package='envoy.extensions.wasm.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/extensions/wasm/v3/wasm.proto\x12\x18\x65nvoy.extensions.wasm.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\x1b\x43\x61pabilityRestrictionConfig\x12l\n\x14\x61llowed_capabilities\x18\x01 \x03(\x0b\x32N.envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry\x1ah\n\x18\x41llowedCapabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.envoy.extensions.wasm.v3.SanitizationConfig:\x02\x38\x01\"\x14\n\x12SanitizationConfig\"\xd1\x01\n\x08VmConfig\x12\r\n\x05vm_id\x18\x01 \x01(\t\x12\x18\n\x07runtime\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x04\x63ode\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.AsyncDataSource\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x61llow_precompiled\x18\x05 \x01(\x08\x12\x1f\n\x17nack_on_code_cache_miss\x18\x06 \x01(\x08\"\x8a\x02\n\x0cPluginConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07root_id\x18\x02 \x01(\t\x12\x37\n\tvm_config\x18\x03 \x01(\x0b\x32\".envoy.extensions.wasm.v3.VmConfigH\x00\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tfail_open\x18\x05 \x01(\x08\x12\\\n\x1d\x63\x61pability_restriction_config\x18\x06 \x01(\x0b\x32\x35.envoy.extensions.wasm.v3.CapabilityRestrictionConfigB\x04\n\x02vm\"X\n\x0bWasmService\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfig\x12\x11\n\tsingleton\x18\x02 \x01(\x08\x42=\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY = _descriptor.Descriptor(
  name='AllowedCapabilitiesEntry',
  full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=427,
)

_CAPABILITYRESTRICTIONCONFIG = _descriptor.Descriptor(
  name='CapabilityRestrictionConfig',
  full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_capabilities', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.allowed_capabilities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=427,
)


_SANITIZATIONCONFIG = _descriptor.Descriptor(
  name='SanitizationConfig',
  full_name='envoy.extensions.wasm.v3.SanitizationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=449,
)


_VMCONFIG = _descriptor.Descriptor(
  name='VmConfig',
  full_name='envoy.extensions.wasm.v3.VmConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vm_id', full_name='envoy.extensions.wasm.v3.VmConfig.vm_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='envoy.extensions.wasm.v3.VmConfig.runtime', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='envoy.extensions.wasm.v3.VmConfig.code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='envoy.extensions.wasm.v3.VmConfig.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_precompiled', full_name='envoy.extensions.wasm.v3.VmConfig.allow_precompiled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nack_on_code_cache_miss', full_name='envoy.extensions.wasm.v3.VmConfig.nack_on_code_cache_miss', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=661,
)


_PLUGINCONFIG = _descriptor.Descriptor(
  name='PluginConfig',
  full_name='envoy.extensions.wasm.v3.PluginConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.wasm.v3.PluginConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_id', full_name='envoy.extensions.wasm.v3.PluginConfig.root_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vm_config', full_name='envoy.extensions.wasm.v3.PluginConfig.vm_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='envoy.extensions.wasm.v3.PluginConfig.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_open', full_name='envoy.extensions.wasm.v3.PluginConfig.fail_open', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability_restriction_config', full_name='envoy.extensions.wasm.v3.PluginConfig.capability_restriction_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='vm', full_name='envoy.extensions.wasm.v3.PluginConfig.vm',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=664,
  serialized_end=930,
)


_WASMSERVICE = _descriptor.Descriptor(
  name='WasmService',
  full_name='envoy.extensions.wasm.v3.WasmService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.wasm.v3.WasmService.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleton', full_name='envoy.extensions.wasm.v3.WasmService.singleton', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1020,
)

_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY.fields_by_name['value'].message_type = _SANITIZATIONCONFIG
_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY.containing_type = _CAPABILITYRESTRICTIONCONFIG
_CAPABILITYRESTRICTIONCONFIG.fields_by_name['allowed_capabilities'].message_type = _CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY
_VMCONFIG.fields_by_name['code'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._ASYNCDATASOURCE
_VMCONFIG.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PLUGINCONFIG.fields_by_name['vm_config'].message_type = _VMCONFIG
_PLUGINCONFIG.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PLUGINCONFIG.fields_by_name['capability_restriction_config'].message_type = _CAPABILITYRESTRICTIONCONFIG
_PLUGINCONFIG.oneofs_by_name['vm'].fields.append(
  _PLUGINCONFIG.fields_by_name['vm_config'])
_PLUGINCONFIG.fields_by_name['vm_config'].containing_oneof = _PLUGINCONFIG.oneofs_by_name['vm']
_WASMSERVICE.fields_by_name['config'].message_type = _PLUGINCONFIG
DESCRIPTOR.message_types_by_name['CapabilityRestrictionConfig'] = _CAPABILITYRESTRICTIONCONFIG
DESCRIPTOR.message_types_by_name['SanitizationConfig'] = _SANITIZATIONCONFIG
DESCRIPTOR.message_types_by_name['VmConfig'] = _VMCONFIG
DESCRIPTOR.message_types_by_name['PluginConfig'] = _PLUGINCONFIG
DESCRIPTOR.message_types_by_name['WasmService'] = _WASMSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CapabilityRestrictionConfig = _reflection.GeneratedProtocolMessageType('CapabilityRestrictionConfig', (_message.Message,), {

  'AllowedCapabilitiesEntry' : _reflection.GeneratedProtocolMessageType('AllowedCapabilitiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY,
    '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry)
    })
  ,
  'DESCRIPTOR' : _CAPABILITYRESTRICTIONCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.CapabilityRestrictionConfig)
  })
_sym_db.RegisterMessage(CapabilityRestrictionConfig)
_sym_db.RegisterMessage(CapabilityRestrictionConfig.AllowedCapabilitiesEntry)

SanitizationConfig = _reflection.GeneratedProtocolMessageType('SanitizationConfig', (_message.Message,), {
  'DESCRIPTOR' : _SANITIZATIONCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.SanitizationConfig)
  })
_sym_db.RegisterMessage(SanitizationConfig)

VmConfig = _reflection.GeneratedProtocolMessageType('VmConfig', (_message.Message,), {
  'DESCRIPTOR' : _VMCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.VmConfig)
  })
_sym_db.RegisterMessage(VmConfig)

PluginConfig = _reflection.GeneratedProtocolMessageType('PluginConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.PluginConfig)
  })
_sym_db.RegisterMessage(PluginConfig)

WasmService = _reflection.GeneratedProtocolMessageType('WasmService', (_message.Message,), {
  'DESCRIPTOR' : _WASMSERVICE,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.WasmService)
  })
_sym_db.RegisterMessage(WasmService)


DESCRIPTOR._options = None
_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY._options = None
_VMCONFIG.fields_by_name['runtime']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.ratelimit.v4alpha import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto',
  package='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha',
  syntax='proto3',
  serialized_options=b'\nUio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alphaB\016RateLimitProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nXenvoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto\x12Genvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha\x1a(envoy/config/ratelimit/v4alpha/rls.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb6\x02\n\tRateLimit\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05stage\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x04 \x01(\x08\x12\\\n\x12rate_limit_service\x18\x05 \x01(\x0b\x32\x36.envoy.config.ratelimit.v4alpha.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:S\x9a\xc5\x88\x1eN\nLenvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v3.RateLimitBq\nUio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alphaB\x0eRateLimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.stage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_deny', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.failure_mode_deny', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_service', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.rate_limit_service', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v3.RateLimit',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=641,
)

_RATELIMIT.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RATELIMIT.fields_by_name['rate_limit_service'].message_type = envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2._RATELIMITSERVICECONFIG
DESCRIPTOR.message_types_by_name['RateLimit'] = _RATELIMIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimit = _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMIT,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit)
  })
_sym_db.RegisterMessage(RateLimit)


DESCRIPTOR._options = None
_RATELIMIT.fields_by_name['domain']._options = None
_RATELIMIT.fields_by_name['stage']._options = None
_RATELIMIT.fields_by_name['rate_limit_service']._options = None
_RATELIMIT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/usage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/usage.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=b'\n\016com.google.apiB\nUsageProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16google/api/usage.proto\x12\ngoogle.api\"j\n\x05Usage\x12\x14\n\x0crequirements\x18\x01 \x03(\t\x12$\n\x05rules\x18\x06 \x03(\x0b\x32\x15.google.api.UsageRule\x12%\n\x1dproducer_notification_channel\x18\x07 \x01(\t\"]\n\tUsageRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12 \n\x18\x61llow_unregistered_calls\x18\x02 \x01(\x08\x12\x1c\n\x14skip_service_control\x18\x03 \x01(\x08\x42l\n\x0e\x63om.google.apiB\nUsageProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3'
)




_USAGE = _descriptor.Descriptor(
  name='Usage',
  full_name='google.api.Usage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='google.api.Usage.requirements', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='google.api.Usage.rules', index=1,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_notification_channel', full_name='google.api.Usage.producer_notification_channel', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=144,
)


_USAGERULE = _descriptor.Descriptor(
  name='UsageRule',
  full_name='google.api.UsageRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='google.api.UsageRule.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unregistered_calls', full_name='google.api.UsageRule.allow_unregistered_calls', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_service_control', full_name='google.api.UsageRule.skip_service_control', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=239,
)

_USAGE.fields_by_name['rules'].message_type = _USAGERULE
DESCRIPTOR.message_types_by_name['Usage'] = _USAGE
DESCRIPTOR.message_types_by_name['UsageRule'] = _USAGERULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Usage = _reflection.GeneratedProtocolMessageType('Usage', (_message.Message,), {
  'DESCRIPTOR' : _USAGE,
  '__module__' : 'google.api.usage_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Usage)
  })
_sym_db.RegisterMessage(Usage)

UsageRule = _reflection.GeneratedProtocolMessageType('UsageRule', (_message.Message,), {
  'DESCRIPTOR' : _USAGERULE,
  '__module__' : 'google.api.usage_pb2'
  # @@protoc_insertion_point(class_scope:google.api.UsageRule)
  })
_sym_db.RegisterMessage(UsageRule)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/cel_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import conformance_service_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/cel_service.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\017CelServiceProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*google/api/expr/v1alpha1/cel_service.proto\x12\x18google.api.expr.v1alpha1\x1a\x32google/api/expr/v1alpha1/conformance_service.proto2\x9d\x02\n\nCelService\x12Z\n\x05Parse\x12&.google.api.expr.v1alpha1.ParseRequest\x1a\'.google.api.expr.v1alpha1.ParseResponse\"\x00\x12Z\n\x05\x43heck\x12&.google.api.expr.v1alpha1.CheckRequest\x1a\'.google.api.expr.v1alpha1.CheckResponse\"\x00\x12W\n\x04\x45val\x12%.google.api.expr.v1alpha1.EvalRequest\x1a&.google.api.expr.v1alpha1.EvalResponse\"\x00\x42r\n\x1c\x63om.google.api.expr.v1alpha1B\x0f\x43\x65lServiceProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_CELSERVICE = _descriptor.ServiceDescriptor(
  name='CelService',
  full_name='google.api.expr.v1alpha1.CelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=125,
  serialized_end=410,
  methods=[
  _descriptor.MethodDescriptor(
    name='Parse',
    full_name='google.api.expr.v1alpha1.CelService.Parse',
    index=0,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._PARSEREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._PARSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='google.api.expr.v1alpha1.CelService.Check',
    index=1,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._CHECKREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Eval',
    full_name='google.api.expr.v1alpha1.CelService.Eval',
    index=2,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._EVALREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._EVALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CELSERVICE)

DESCRIPTOR.services_by_name['CelService'] = _CELSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import protocol_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto',
  package='envoy.extensions.upstreams.http.v4alpha',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.upstreams.http.v4alphaB\030HttpProtocolOptionsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto\x12\'envoy.extensions.upstreams.http.v4alpha\x1a(envoy/config/core/v4alpha/protocol.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe1\x0c\n\x13HttpProtocolOptions\x12T\n\x1c\x63ommon_http_protocol_options\x18\x01 \x01(\x0b\x32..envoy.config.core.v4alpha.HttpProtocolOptions\x12^\n\x1eupstream_http_protocol_options\x18\x02 \x01(\x0b\x32\x36.envoy.config.core.v4alpha.UpstreamHttpProtocolOptions\x12o\n\x14\x65xplicit_http_config\x18\x03 \x01(\x0b\x32O.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfigH\x00\x12~\n\x1euse_downstream_protocol_config\x18\x04 \x01(\x0b\x32T.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfigH\x00\x12\x62\n\x0b\x61uto_config\x18\x05 \x01(\x0b\x32K.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfigH\x00\x1a\xf6\x02\n\x12\x45xplicitHttpConfig\x12P\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptionsH\x00\x12Q\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptionsH\x00\x12Q\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http3ProtocolOptionsH\x00:P\x9a\xc5\x88\x1eK\nIenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfigB\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xe2\x02\n\x17UseDownstreamHttpConfig\x12N\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptions\x12O\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptions\x12O\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http3ProtocolOptions:U\x9a\xc5\x88\x1eP\nNenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfig\x1a\xff\x01\n\x0e\x41utoHttpConfig\x12N\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptions\x12O\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptions:L\x9a\xc5\x88\x1eG\nEenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfig:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.upstreams.http.v3.HttpProtocolOptionsB \n\x19upstream_protocol_options\x12\x03\xf8\x42\x01\x42[\n5io.envoyproxy.envoy.extensions.upstreams.http.v4alphaB\x18HttpProtocolOptionsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG = _descriptor.Descriptor(
  name='ExplicitHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http3_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http3_protocol_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036K\nIenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='protocol_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.protocol_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=793,
  serialized_end=1167,
)

_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG = _descriptor.Descriptor(
  name='UseDownstreamHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http3_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http3_protocol_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036P\nNenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1524,
)

_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG = _descriptor.Descriptor(
  name='AutoHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036G\nEenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1782,
)

_HTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='HttpProtocolOptions',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.common_http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.upstream_http_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_http_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.explicit_http_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_downstream_protocol_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.use_downstream_protocol_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.auto_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG, _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG, _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.upstreams.http.v3.HttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='upstream_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.upstream_protocol_options',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=246,
  serialized_end=1879,
)

_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP3PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http3_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP3PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['common_http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['upstream_http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._UPSTREAMHTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'].message_type = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG
_HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'].message_type = _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG
_HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'].message_type = _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
DESCRIPTOR.message_types_by_name['HttpProtocolOptions'] = _HTTPPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpProtocolOptions = _reflection.GeneratedProtocolMessageType('HttpProtocolOptions', (_message.Message,), {

  'ExplicitHttpConfig' : _reflection.GeneratedProtocolMessageType('ExplicitHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig)
    })
  ,

  'UseDownstreamHttpConfig' : _reflection.GeneratedProtocolMessageType('UseDownstreamHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig)
    })
  ,

  'AutoHttpConfig' : _reflection.GeneratedProtocolMessageType('AutoHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig)
    })
  ,
  'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions)
  })
_sym_db.RegisterMessage(HttpProtocolOptions)
_sym_db.RegisterMessage(HttpProtocolOptions.ExplicitHttpConfig)
_sym_db.RegisterMessage(HttpProtocolOptions.UseDownstreamHttpConfig)
_sym_db.RegisterMessage(HttpProtocolOptions.AutoHttpConfig)


DESCRIPTOR._options = None
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']._options = None
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']._options = None
_HTTPPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/eds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import endpoint_pb2 as envoy_dot_api_dot_v2_dot_endpoint__pb2

from envoy.api.v2.endpoint_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/eds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010EdsProtoP\001\210\001\001\362\230\376\217\005\033\022\031envoy.service.endpoint.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/eds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/endpoint.proto\"\n\n\x08\x45\x64sDummy2\x80\x03\n\x18\x45ndpointDiscoveryService\x12X\n\x0fStreamEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x61\n\x0e\x44\x65ltaEndpoints\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0e\x46\x65tchEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v2/discovery:endpoints\x82\xd3\xe4\x93\x02\x03:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.api.v2.ClusterLoadAssignmentBT\n\x1aio.envoyproxy.envoy.api.v2B\x08\x45\x64sProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_endpoint__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_endpoint__pb2.DESCRIPTOR,])




_EDSDUMMY = _descriptor.Descriptor(
  name='EdsDummy',
  full_name='envoy.api.v2.EdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=236,
)

DESCRIPTOR.message_types_by_name['EdsDummy'] = _EDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdsDummy = _reflection.GeneratedProtocolMessageType('EdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _EDSDUMMY,
  '__module__' : 'envoy.api.v2.eds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.EdsDummy)
  })
_sym_db.RegisterMessage(EdsDummy)


DESCRIPTOR._options = None

_ENDPOINTDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='EndpointDiscoveryService',
  full_name='envoy.api.v2.EndpointDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007$\n\"envoy.api.v2.ClusterLoadAssignment',
  create_key=_descriptor._internal_create_key,
  serialized_start=239,
  serialized_end=623,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.StreamEndpoints',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.DeltaEndpoints',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.FetchEndpoints',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v2/discovery:endpoints\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENDPOINTDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['EndpointDiscoveryService'] = _ENDPOINTDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto',
  package='envoy.extensions.filters.http.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\023ProcessingModeProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDenvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x12.envoy.extensions.filters.http.ext_proc.v3alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd0\x06\n\x0eProcessingMode\x12t\n\x13request_header_mode\x18\x01 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12u\n\x14response_header_mode\x18\x02 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x11request_body_mode\x18\x03 \x01(\x0e\x32K.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x12response_body_mode\x18\x04 \x01(\x0e\x32K.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12u\n\x14request_trailer_mode\x18\x05 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12v\n\x15response_trailer_mode\x18\x06 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"1\n\x0eHeaderSendMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04SEND\x10\x01\x12\x08\n\x04SKIP\x10\x02\"J\n\x0c\x42odySendMode\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08STREAMED\x10\x01\x12\x0c\n\x08\x42UFFERED\x10\x02\x12\x14\n\x10\x42UFFERED_PARTIAL\x10\x03\x42\x65\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\x13ProcessingModeProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_PROCESSINGMODE_HEADERSENDMODE = _descriptor.EnumDescriptor(
  name='HeaderSendMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=900,
  serialized_end=949,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODE_HEADERSENDMODE)

_PROCESSINGMODE_BODYSENDMODE = _descriptor.EnumDescriptor(
  name='BodySendMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUFFERED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUFFERED_PARTIAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=951,
  serialized_end=1025,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODE_BODYSENDMODE)


_PROCESSINGMODE = _descriptor.Descriptor(
  name='ProcessingMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_header_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_header_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_header_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_header_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_body_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_body_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailer_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_trailer_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailer_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_trailer_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSINGMODE_HEADERSENDMODE,
    _PROCESSINGMODE_BODYSENDMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=1025,
)

_PROCESSINGMODE.fields_by_name['request_header_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['response_header_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['request_body_mode'].enum_type = _PROCESSINGMODE_BODYSENDMODE
_PROCESSINGMODE.fields_by_name['response_body_mode'].enum_type = _PROCESSINGMODE_BODYSENDMODE
_PROCESSINGMODE.fields_by_name['request_trailer_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['response_trailer_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE_HEADERSENDMODE.containing_type = _PROCESSINGMODE
_PROCESSINGMODE_BODYSENDMODE.containing_type = _PROCESSINGMODE
DESCRIPTOR.message_types_by_name['ProcessingMode'] = _PROCESSINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingMode = _reflection.GeneratedProtocolMessageType('ProcessingMode', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGMODE,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.processing_mode_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode)
  })
_sym_db.RegisterMessage(ProcessingMode)


DESCRIPTOR._options = None
_PROCESSINGMODE.fields_by_name['request_header_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_header_mode']._options = None
_PROCESSINGMODE.fields_by_name['request_body_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_body_mode']._options = None
_PROCESSINGMODE.fields_by_name['request_trailer_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_trailer_mode']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto',
  package='envoy.config.filter.network.redis_proxy.v2',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\017RedisProxyProtoP\001\362\230\376\217\0051\022/envoy.extensions.filters.network.redis_proxy.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto\x12*envoy.config.filter.network.redis_proxy.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xef\x0b\n\nRedisProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x19\n\x07\x63luster\x18\x02 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x63\n\x08settings\x18\x03 \x01(\x0b\x32G.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11latency_in_micros\x18\x04 \x01(\x08\x12Z\n\rprefix_routes\x18\x05 \x01(\x0b\x32\x43.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes\x12G\n\x18\x64ownstream_auth_password\x18\x06 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x1a\x92\x04\n\x10\x43onnPoolSettings\x12\x37\n\nop_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x08\x01\x12\x1a\n\x12\x65nable_hashtagging\x18\x02 \x01(\x08\x12\x1a\n\x12\x65nable_redirection\x18\x03 \x01(\x08\x12$\n\x1cmax_buffer_size_before_flush\x18\x04 \x01(\r\x12\x37\n\x14\x62uffer_flush_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n max_upstream_unknown_connections\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14\x65nable_command_stats\x18\x08 \x01(\x08\x12q\n\x0bread_policy\x18\x07 \x01(\x0e\x32R.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.ReadPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"U\n\nReadPolicy\x12\n\n\x06MASTER\x10\x00\x12\x11\n\rPREFER_MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\x12\x12\n\x0ePREFER_REPLICA\x10\x03\x12\x07\n\x03\x41NY\x10\x04\x1a\xed\x04\n\x0cPrefixRoutes\x12Y\n\x06routes\x18\x01 \x03(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x12\x18\n\x10\x63\x61se_insensitive\x18\x02 \x01(\x08\x12#\n\x11\x63\x61tch_all_cluster\x18\x03 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x62\n\x0f\x63\x61tch_all_route\x18\x04 \x01(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x1a\xde\x02\n\x05Route\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x15\n\rremove_prefix\x18\x02 \x01(\x08\x12\x18\n\x07\x63luster\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12|\n\x15request_mirror_policy\x18\x04 \x03(\x0b\x32].envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy\x1a\x95\x01\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x45\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12\x1d\n\x15\x65xclude_read_commands\x18\x03 \x01(\x08\"T\n\x14RedisProtocolOptions\x12<\n\rauth_password\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x42\x8c\x01\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\x0fRedisProxyProtoP\x01\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.redis_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_REDISPROXY_CONNPOOLSETTINGS_READPOLICY = _descriptor.EnumDescriptor(
  name='ReadPolicy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.ReadPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MASTER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_MASTER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLICA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_REPLICA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1172,
  serialized_end=1257,
)
_sym_db.RegisterEnumDescriptor(_REDISPROXY_CONNPOOLSETTINGS_READPOLICY)


_REDISPROXY_CONNPOOLSETTINGS = _descriptor.Descriptor(
  name='ConnPoolSettings',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_timeout', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.op_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hashtagging', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_hashtagging', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_redirection', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_redirection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_buffer_size_before_flush', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.max_buffer_size_before_flush', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_timeout', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.buffer_flush_timeout', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_upstream_unknown_connections', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.max_upstream_unknown_connections', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_command_stats', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_command_stats', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_policy', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.read_policy', index=7,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDISPROXY_CONNPOOLSETTINGS_READPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=1257,
)

_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY = _descriptor.Descriptor(
  name='RequestMirrorPolicy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_fraction', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.runtime_fraction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_read_commands', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.exclude_read_commands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1881,
)

_REDISPROXY_PREFIXROUTES_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.remove_prefix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_mirror_policy', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.request_mirror_policy', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1531,
  serialized_end=1881,
)

_REDISPROXY_PREFIXROUTES = _descriptor.Descriptor(
  name='PrefixRoutes',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.case_insensitive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catch_all_cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.catch_all_cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catch_all_route', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.catch_all_route', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1881,
)

_REDISPROXY = _descriptor.Descriptor(
  name='RedisProxy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_in_micros', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.latency_in_micros', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_routes', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.prefix_routes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_auth_password', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.downstream_auth_password', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_CONNPOOLSETTINGS, _REDISPROXY_PREFIXROUTES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=1881,
)


_REDISPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='RedisProtocolOptions',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_password', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions.auth_password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1967,
)

_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['buffer_flush_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['max_upstream_unknown_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy'].enum_type = _REDISPROXY_CONNPOOLSETTINGS_READPOLICY
_REDISPROXY_CONNPOOLSETTINGS.containing_type = _REDISPROXY
_REDISPROXY_CONNPOOLSETTINGS_READPOLICY.containing_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['runtime_fraction'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.containing_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['request_mirror_policy'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY
_REDISPROXY_PREFIXROUTES_ROUTE.containing_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY_PREFIXROUTES.fields_by_name['routes'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_route'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.containing_type = _REDISPROXY
_REDISPROXY.fields_by_name['settings'].message_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY.fields_by_name['prefix_routes'].message_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY.fields_by_name['downstream_auth_password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
DESCRIPTOR.message_types_by_name['RedisProxy'] = _REDISPROXY
DESCRIPTOR.message_types_by_name['RedisProtocolOptions'] = _REDISPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisProxy = _reflection.GeneratedProtocolMessageType('RedisProxy', (_message.Message,), {

  'ConnPoolSettings' : _reflection.GeneratedProtocolMessageType('ConnPoolSettings', (_message.Message,), {
    'DESCRIPTOR' : _REDISPROXY_CONNPOOLSETTINGS,
    '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings)
    })
  ,

  'PrefixRoutes' : _reflection.GeneratedProtocolMessageType('PrefixRoutes', (_message.Message,), {

    'Route' : _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {

      'RequestMirrorPolicy' : _reflection.GeneratedProtocolMessageType('RequestMirrorPolicy', (_message.Message,), {
        'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY,
        '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)
        })
      ,
      'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE,
      '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route)
      })
    ,
    'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES,
    '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes)
    })
  ,
  'DESCRIPTOR' : _REDISPROXY,
  '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy)
  })
_sym_db.RegisterMessage(RedisProxy)
_sym_db.RegisterMessage(RedisProxy.ConnPoolSettings)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)

RedisProtocolOptions = _reflection.GeneratedProtocolMessageType('RedisProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _REDISPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions)
  })
_sym_db.RegisterMessage(RedisProtocolOptions)


DESCRIPTOR._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout']._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_cluster']._options = None
_REDISPROXY.fields_by_name['stat_prefix']._options = None
_REDISPROXY.fields_by_name['cluster']._options = None
_REDISPROXY.fields_by_name['settings']._options = None
_REDISPROXY.fields_by_name['downstream_auth_password']._options = None
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v4alpha/outlier_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/cluster/v4alpha/outlier_detection.proto',
  package='envoy.config.cluster.v4alpha',
  syntax='proto3',
  serialized_options=b'\n*io.envoyproxy.envoy.config.cluster.v4alphaB\025OutlierDetectionProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/config/cluster/v4alpha/outlier_detection.proto\x12\x1c\x65nvoy.config.cluster.v4alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8f\x0c\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11max_ejection_time\x18\x15 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:/\x9a\xc5\x88\x1e*\n(envoy.config.cluster.v3.OutlierDetectionBM\n*io.envoyproxy.envoy.config.cluster.v4alphaB\x15OutlierDetectionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_OUTLIERDETECTION = _descriptor.Descriptor(
  name='OutlierDetection',
  full_name='envoy.config.cluster.v4alpha.OutlierDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consecutive_5xx', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_5xx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.cluster.v4alpha.OutlierDetection.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_ejection_time', full_name='envoy.config.cluster.v4alpha.OutlierDetection.base_ejection_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ejection_percent', full_name='envoy.config.cluster.v4alpha.OutlierDetection.max_ejection_percent', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_5xx', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_5xx', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_success_rate', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_success_rate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_minimum_hosts', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_minimum_hosts', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_request_volume', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_request_volume', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_stdev_factor', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_stdev_factor', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consecutive_gateway_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_gateway_failure', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_gateway_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_gateway_failure', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='split_external_local_origin_errors', full_name='envoy.config.cluster.v4alpha.OutlierDetection.split_external_local_origin_errors', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consecutive_local_origin_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_local_origin_failure', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_local_origin_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_local_origin_failure', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_local_origin_success_rate', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_local_origin_success_rate', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_threshold', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_threshold', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_failure_percentage', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_failure_percentage', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_failure_percentage_local_origin', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_failure_percentage_local_origin', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_minimum_hosts', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_minimum_hosts', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_request_volume', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_request_volume', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ejection_time', full_name='envoy.config.cluster.v4alpha.OutlierDetection.max_ejection_time', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.cluster.v3.OutlierDetection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=1793,
)

_OUTLIERDETECTION.fields_by_name['consecutive_5xx'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OUTLIERDETECTION.fields_by_name['base_ejection_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OUTLIERDETECTION.fields_by_name['max_ejection_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_success_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_minimum_hosts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_request_volume'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_stdev_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['consecutive_gateway_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['consecutive_local_origin_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_minimum_hosts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_request_volume'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['max_ejection_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['OutlierDetection'] = _OUTLIERDETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OutlierDetection = _reflection.GeneratedProtocolMessageType('OutlierDetection', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERDETECTION,
  '__module__' : 'envoy.config.cluster.v4alpha.outlier_detection_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.OutlierDetection)
  })
_sym_db.RegisterMessage(OutlierDetection)


DESCRIPTOR._options = None
_OUTLIERDETECTION.fields_by_name['interval']._options = None
_OUTLIERDETECTION.fields_by_name['base_ejection_time']._options = None
_OUTLIERDETECTION.fields_by_name['max_ejection_percent']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._options = None
_OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._options = None
_OUTLIERDETECTION.fields_by_name['max_ejection_time']._options = None
_OUTLIERDETECTION._options = None
# @@protoc_insertion_point(module_scope)
